==> jc-1.4.0.tar.gz: java/lang/VMThrowable.h <==
// final class java.lang.VMThrowable

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c8d6a6ffc5c1acc1 java_lang_VMThrowable

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_VMThrowable_H_
#define _JC_java_lang_VMThrowable_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Throwable$object;
struct _jc_java_lang_VMThrowable$object;

// Typedefs
typedef struct _jc_java_lang_VMThrowable$sub_refs	_jc_java_lang_VMThrowable$sub_refs;
typedef struct _jc_java_lang_VMThrowable$sub_nonrefs	_jc_java_lang_VMThrowable$sub_nonrefs;
typedef struct _jc_java_lang_VMThrowable$refs	_jc_java_lang_VMThrowable$refs;
typedef struct _jc_java_lang_VMThrowable$nonrefs	_jc_java_lang_VMThrowable$nonrefs;
typedef struct _jc_java_lang_VMThrowable$object	_jc_java_lang_VMThrowable$object;

typedef const struct _jc_java_lang_VMThrowable$vmethods	_jc_java_lang_VMThrowable$vmethods;
typedef const struct _jc_java_lang_VMThrowable$vtable	_jc_java_lang_VMThrowable$vtable;
typedef const struct _jc_java_lang_VMThrowable$vtype	_jc_java_lang_VMThrowable$vtype;

// Constructors
extern void _jc_java_lang_VMThrowable$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_VMThrowable$object *);

// Virtual methods
extern _jc_object_array *_jc_java_lang_VMThrowable$method$getStackTrace$6bf04a7562bb9b69(_jc_env *, struct _jc_java_lang_VMThrowable$object *, struct _jc_java_lang_Throwable$object *);

// Virtual method descriptors
extern _jc_method _jc_java_lang_VMThrowable$method_info$getStackTrace$6bf04a7562bb9b69;

// Static methods
extern struct _jc_java_lang_VMThrowable$object *_jc_java_lang_VMThrowable$method$fillInStackTrace$78894ac70fa4c0a5(_jc_env *, struct _jc_java_lang_Throwable$object *);

// Virtual methods structure
struct _jc_java_lang_VMThrowable$vmethods {
	_jc_object_array	*(*getStackTrace$6bf04a7562bb9b69)(_jc_env *, struct _jc_java_lang_VMThrowable$object *, struct _jc_java_lang_Throwable$object *);
};

// Vtable
struct _jc_java_lang_VMThrowable$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_VMThrowable$vmethods	java_lang_VMThrowable;
};

// Vtype
struct _jc_java_lang_VMThrowable$vtype {
	_jc_type			type;
	_jc_java_lang_VMThrowable$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_VMThrowable$sub_refs {
	_jc_byte_array	*vmdata;
};

// Reference instance fields (object)
struct _jc_java_lang_VMThrowable$refs {
    _jc_java_lang_VMThrowable$sub_refs	java_lang_VMThrowable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_VMThrowable$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_VMThrowable$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_VMThrowable$sub_nonrefs	java_lang_VMThrowable;
};

// Object instance structure
struct _jc_java_lang_VMThrowable$object {
	_jc_java_lang_VMThrowable$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_VMThrowable$vtype	*vtype;
	_jc_java_lang_VMThrowable$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_VMThrowable$vtype _jc_java_lang_VMThrowable$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_VMThrowable, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_VMThrowable$class_object;

#endif	/* _JC_java_lang_VMThrowable_H_ */

==> jc-1.4.6.tar.gz: java/lang/VMThrowable.h <==
// final class java.lang.VMThrowable

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c8d6a6ffc5c1acc1 java_lang_VMThrowable

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_VMThrowable_H_
#define _JC_java_lang_VMThrowable_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Throwable$object;
struct _jc_java_lang_VMThrowable$object;

// Typedefs
typedef struct _jc_java_lang_VMThrowable$sub_refs	_jc_java_lang_VMThrowable$sub_refs;
typedef struct _jc_java_lang_VMThrowable$sub_nonrefs	_jc_java_lang_VMThrowable$sub_nonrefs;
typedef struct _jc_java_lang_VMThrowable$refs	_jc_java_lang_VMThrowable$refs;
typedef struct _jc_java_lang_VMThrowable$nonrefs	_jc_java_lang_VMThrowable$nonrefs;
typedef struct _jc_java_lang_VMThrowable$object	_jc_java_lang_VMThrowable$object;

typedef const struct _jc_java_lang_VMThrowable$vmethods	_jc_java_lang_VMThrowable$vmethods;
typedef const struct _jc_java_lang_VMThrowable$vtable	_jc_java_lang_VMThrowable$vtable;
typedef const struct _jc_java_lang_VMThrowable$vtype	_jc_java_lang_VMThrowable$vtype;

// Constructors
extern void _jc_java_lang_VMThrowable$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_VMThrowable$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_java_lang_VMThrowable$method$getStackTrace$6bf04a7562bb9b69(_jc_env *, struct _jc_java_lang_VMThrowable$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_lang_VMThrowable$method_info$getStackTrace$6bf04a7562bb9b69;

// Static methods
extern struct _jc_java_lang_VMThrowable$object *_jc_java_lang_VMThrowable$method$fillInStackTrace$78894ac70fa4c0a5(_jc_env *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_VMThrowable$vmethods {
	_jc_object_array	*(*getStackTrace$6bf04a7562bb9b69)(_jc_env *, struct _jc_java_lang_VMThrowable$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_lang_VMThrowable$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_VMThrowable$vmethods	java_lang_VMThrowable;
};

// Vtype
struct _jc_java_lang_VMThrowable$vtype {
	_jc_type			type;
	_jc_java_lang_VMThrowable$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_VMThrowable$sub_refs {
	_jc_byte_array	*vmdata;
};

// Reference instance fields (object)
struct _jc_java_lang_VMThrowable$refs {
    _jc_java_lang_VMThrowable$sub_refs	java_lang_VMThrowable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_VMThrowable$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_VMThrowable$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_VMThrowable$sub_nonrefs	java_lang_VMThrowable;
};

// Object instance structure
struct _jc_java_lang_VMThrowable$object {
	_jc_java_lang_VMThrowable$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_VMThrowable$vtype	*vtype;
	_jc_java_lang_VMThrowable$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_VMThrowable$vtype _jc_java_lang_VMThrowable$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_VMThrowable, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_VMThrowable$class_object;

#endif	/* _JC_java_lang_VMThrowable_H_ */
